Monty Python's Flying Circus: Just the Words - Episode 7

# Episode Seven: You're no fun any more

Camel spotting
You're no fun any more
The audit
Science fiction sketch
Man turns into Scotsman
Police station
Blancmanges playing tennis

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A long hilly scar of land; on either side trees. The track comes straight down from the horizon to camera in valley. At the top of the hill we hear running and heavy breathing. The 'It's' man appears. He runs down the valley to camera but fails to say his line:
Voice Off | (prompting) It's...no...no...it's...it's...it's...
It's Man | (finally) It's...
| By the miracle of money we swing into a fantastically expensive opening animation sequence, produced by one of America's very own drop-outs. In the country. Interviewer with microphone. Behind him a man sits on a wall, with clip-board, binoculars and spotting gear.
Interviewer | Good evening. Tonight we're going to take a hard tough abrasive look at camel spotting. Hello.
Spotter | Hello Peter.
Interviewer | Now tell me, what exactly are you doing?
Spotter | Er well, I'm camel spotting. I'm spotting to see if there are any camels that I can spot, and put them down in my camel spotting book.
Interviewer | Good. And how many camels have you spotted so far?
Spotter | Oh, well so far Peter, up to the present moment, I've spotted nearly, ooh, nearly one.
Interviewer | Nearly one?
Spotter | Er, call it none.
Interviewer | Fine. And er how long have you been here?
Spotter | Three years.
Interviewer | So, in, er, three years you've spotted no camels?
Spotter | Yes in only three years. Er, I tell a lie, four, be fair, five. I've been camel spotting for just the seven years. Before that of course I was a Yeti spotter.
Interviewer | A Yeti spotter, that must have been extremely interesting.
Spotter | Oh, it was extremely interesting, very, very - quite... it was dull; dull, dull, dull, oh God it was dull. Sitting in the Waterloo waiting room. Course once you've seen one Yeti you've seen them all.
Interviewer | And have you seen them all?
Spotter | Well I've seen one. Well a little one... a picture of a... I've heard about them.
Interviewer | Well, now tell me, what do you do when you spot a camel?
Spotter | Er, I take its number.
Interviewer | Camels don't have numbers.
Spotter | Ah, well you've got to know where to look. Er, they're on the side of the engine above the piston box.
Interviewer | What?
Spotter | Ah - of course you've got to make sure it's not a dromedary. 'Cos if it's a dromedary it goes in the dromedary book.
Interviewer | Well how do you tell if it's a dromedary?
Spotter | Ah well, a dromedary has one hump and a camel has a refreshment car, buffet, and ticket collector.
Interviewer | Mr Sopwith, aren't you in fact a train spotter?
Spotter | What?
Interviewer | Don't you in fact spot trains?
Spotter | Oh, you're no fun anymore.
| ANIMATION: Then a girl in bed. Count Dracula enters. The girl reveals her neck. The vampire goes to kiss her but his fangs fall out.
Girl (Donna Reading) | Oh, you're no fun anymore.
| A man at the yardarm being lashed.
Lasher | .. thirty-nine... forty. All right, cut him down, Mr Fuller.
Lashee | Oh you're no fun anymore.
| Back to camel spotter.
Spotter | Now if anybody else pinches my phrase I'll throw them under a camel.
Interviewer | (giggling) If you can spot one.
| Spotter gives him a dirty look. Knight in armour appears beside him. He hits interviewer with chicken. Cut to a small board meeting. An accountant stands up an reads...
Accountant | Lady Chairman, sir, shareholders, ladies and gentlemen. I have great pleasure in announcing that owing to a cutback on surplus expenditure of twelve million Canadian dollars, plus a refund of seven and a half million Deutschmarks from the Swiss branch, and in addition adding the debenture preference stock of the three and three quarter million to the directors' reserve currency account of seven and a half million, plus an upward expenditure margin of eleven and a half thousand lira, due to a rise in capital investment of ten million pounds, this firm last year made a complete profit of a shilling.
Chairman | A shilling Wilkins?
Accountant | Er, roughly, yes sir.
Chairman | Wilkins, I am the Chairman of a multi-million pound corporation and you are a very new chartered Accountant. Isn't it possible there may have been some mistake?
Accountant | Well that's very kind of you sir, but I don't think I'm ready to be Chairman yet.
Board Member | Wilkins, Wilkins. This shilling, is it net or gross?
Accountant | It's British sir.
Chairman | Yes, has tax been paid on it?
Accountant | Yes, this is after tax. Owing to the rigorous bite of the income tax five pence of a further sixpence was swallowed up in tax.
Board Member | Five pence of a further sixpence?
Accountant | (eagerly) Yes sir.
Chairman | Five pence of a further sixpence?
Accountant | That's right sir.
Chairman | Then where is the other penny?
Accountant | ... Er.
Board Member | That makes you a penny short Wilkins. Where is it?
Accountant | ... Erm.
Chairman | Wilkins?
Accountant | (in tears) I embezzled it sir.
Chairman | What all of it?
Accountant | Yes all of it.
Board Member | You naughty person.
Accountant | It's my first. Please be gentle with me.
Chairman | I'm afraid it's my unpleasant duty to inform you that you're fired.
Accountant | Oh please, please.
Chairman | No, out!
Accountant | (crying) Oh ... (he leaves)
Chairman | Yes, there's no place for sentiment in big business.
| He goes over to a wall plaque 'There is no place for sentiment in Big Business'. He turns it over. On the back it says 'He's right you know'.
Bishop | (to Chairman) Oh you're no fun anymore.
| Camel Spotting man comes running in shouting.
Spotter | I heard that. Who said that?
All | (pointing at the bishop) He did! He did!
Bishop | No I didn't.
All | Ooh!
Spotter | Right!
| Shot of the bishop bound and gagged and tied across a railway line.
Voice Over | Here is the address to complain to ...
| CAPTION: 'MR ALBERT SPIM, I,OOO,OO8 LONDON ROAD, OXFORD' But he reads:
Voice Over | The Royal Frog Trampling Institute, 16 Rayners Lane, London, W.C. Fields. I'll just repeat that...
| CAPTION: 'FLIGHT LT. & PREBENDARY ETHEL MORRIS, THE DIMPLES, THAXTED, NR BUENOS AIRES' He reads over it:
Voice Over | Tristram and Isolde Phillips, 7.30 Covent Garden Saturday (near Sunday) and afterwards at the Inigo Jones Fish Emporium.
| Cut to Jewish figure.
Jewish Figure | And they want to put the licence fee up?
| Cut to a photo of a man with pipe.
Voice Over | And now here is a reminder about leaving your radio on during the night. Leave your radio on during the night.
| Cut to redcoat.
Redcoat | A little joke, a little jest. Nothing to worry about ladies and gentlemen. Now we've got some science fiction for you, some sci-fi, something to send the shivers up your spine, send the creepy crawlies down your lager and limes. All the lads have contributed to it, it's a little number entitled, Science Fiction Sketch...
| Zoom through the galaxy to the solar system.
American Voice | (very resonant) The Universe consists of a billion, billion galaxies... 77,000,000,000 miles across, and every galaxy is made up of a billion, zillion stars and around these stars circle a billion planets, and of all of these planets the greenest and the pleasantest is the planet Earth, in the system of Sol, in the Galaxy known as the Milky Way ... And it was to this world that creatures of an alien planet came ... to conquer and destroy the very heart of civilization...
| Mix into close-up of railway station sign: 'New Pudsey'. Pull out to mid-shot of a couple walking towards camera. They are middle-aged. He (Graham) wears a cricket blazer and grey flannels and a carrier bag. She (Eric) wears a fussy print dress.
American Voice | (gently) It was a day like any other and Mr and Mrs Samuel Brainsample were a perfectly ordinary couple, leading perfectly ordinary lives - the sort of people to whom nothing extraordinary ever happened, and not the kind of people to be the centre of one of the most astounding incidents in the history of mankind ... So let's forget about them and follow instead the destiny of this man ... (camera pans off them; they both look disappointed; camera picks up instead a smart little business man, in bowler, briefcase and pinstripes) ... Harold Potter, gardener, and tax official, first victim of Creatures from another Planet.
| Weird electronic music. Sinister atmosphere. Follow him out of station. Cut-away to flying saucer, over day skyline. Back to Potter as he walks up suburban road. Back to flying saucer. It bleeps as if it has seen its prey and changes direction. Cut back to Potter just about to open his front gate. Shot from over the other side of the road. Cut to flying saucer sending down ray. Potter freezes . . . shivers and turns into a Scotsman with kilt, and red beard. His hand jerks out in front of him and he spins round and scuttles up road in fast motion, to the accompaniment of bagpipe music. Cut to close-up of newspaper with banner headline: 'Man turns into a Scotsman'.
Newsvendor's Voice | Read all abaht it! Read all abaht it! Man turns into Scotsman!
| Mix through to Potter's front gate. His wife is being interviewed by obvious plainclothes man.
Inspector | Mrs Potter - you knew Harold Potter quite well I believe?
Wife | Oh yes quite well.
Inspector | Yes.
Wife | He was my husband.
Inspector | Yes. And, er, he never showed any inclination towards being a Scotsman before this happened?
Wife | (shocked) No, no, not at all. He was not that sort of person...
Inspector | He didn't wear a kilt or play the bagpipes?
Wife | No, no.
Inspector | He never got drunk at night or bought home black puddings?
Wife | No, no. Not at all.
Inspector | He didn't have an inadequate brain capacity?
Wife | No, no, not at all.
Inspector | I see. So by your account Harold Potter was a perfectly ordinary Englishman without any tendency towards being a Scotsman whatsoever?
Wife | Absolutely, yes. (suddenly remembering) Mind you he did always watch Dr Finlay on television.
Inspector | Ah-hah! ... Well that's it, you see. That's how it starts.
Wife | I beg your pardon?
Inspector | Well you see Scottishness starts with little things like that, and works up. You see, people don't just turn into a Scotsman for no reason at all... (goes rigid: with Scots accent:) No further questions!
| The words are hardly out of his mouth when he turns into a Scotsman and spins round and disappears up road in fast motion. Pan with him. Cut to bus queue: man in a city suit and bowler hat suddenly changes into a Scotsman with beard, twizzles round and speeds out of shot. Cut to street policeman pointing way for woman with a pram. Suddenly he changes into a Scotsman and scuffles out of shot. She looks aghast for a moment and then she too changes into a Scotsman and hurtles off after him. The baby suddenly develops a beard and the pram follows her. Single shot of black jazz musician in cellar blowing a blues sax solo. He changes and whizzes off. Squad of soldiers being drilled. Suddenly they all change into bearded Scotsmen and race off in unison. Pan with them past sign: 'Welsh Guard'. Quick animated shot of flying saucer disappearing over city skyline. Cut to big close-up of passionate kiss. It goes on for some moments. Foggy lens... romantic music. Keep on big close-up as they talk. She is none too intelligent.
She (Donna Reading) | Charles...
Charles | Darling...
She | Charles...
Charles | Darling, darling...
She | Charles... there's something I've got to tell you...
Charles | What is it darling?
She | It's daddy ... he's turned into a Scotsman...
Charles | What! Mr Llewellyn?
She | Yes, Charles. Help me, please help me.
Charles | But what can I do?
She | Surely, Charles, you're the Chief Scientist at the Anthropological Research Institute, at Butley Down - an expert in what makes people change from one nationality to another.
Charles | So I am! (pull out to reveal they are in a laboratory; he is in a white coat, she is in something absurdly sexy) This is right up my street!
She | Oh good.
Charles | Now first of all, why would anyone turn into a Scotsman?
She | (tentatively) Em, for business reasons?
Charles | No, no! Only because he has no control over his own destiny! Look I'll show you...
| He presses a button on a control board and a laboratory TV screen lights op with the words 'only because they have no control over their own destinies'.
She | I see.
Charles | Yes! So this means that some person or persons unknown is turning all these people into Scotsmen...
She | Oh, what kind of heartless fiend could do that to a man?
Charles | I don't know ... I don't know ... all I know is that these people are streaming north of the border at the rate of thousands every hour. If we don't act fast, Scotland will be choked with Scotsmen...
She | Ooh!...
| Zoom in on her face. Cut to as many bearded Scotsmen as possible, hurtling through wood in fast motion. Follow them, ending up with skyline shot as per 'Seventh Seal'. They all still have the arm outstretched in front of them and as always they are accompanied by bagpipe music. Shot of border with large notice: 'Scotland Welcomes You'.
American Voice | Soon Scotland was full of Scotsmen. The over-crowding was pitiful.
| They all dash across harder and then stop abruptly once they're over. They stand around looking lost.
American Voice | Three men to a caber.
| Cut to three Scotsmen tossing one caber. Cut to Scots wife in bed with bearded husband. Pull back to reveal five other Scotsmen in the bed. Short but brilliant piece of animation from T. Gilliam to show England emptying of people and Scotland filling up, ending with a till sound and a till sign coming up out of England reading: 'Empty'. Track into England. Film of a deserted street. Wind, a dog sniffing, newspaper blowing along street. Close-up sign on shop door 'Gone to lunch Scotland'. Close-up another sign on a shop door.' 'McClosed'. Shop sign: McWoolworths & Co'.
American Voice | For the few who remained, life was increasingly difficult.
| Man suddenly folds up newspaper and runs round corner. Re-emerges driving bus. Drives it halfway to stop and then leaps out with bus still moving. Runs to stop, and puts out hand. Bus stops. He leaps on, rings bell, runs round to front and drives the bus off again. As bus drives out of frame we just see a couple of Scotsmen flashing past camera with arms outstretched. Pan slowly round empty football stadium. Eventually we pick up a solitary spectator, halfway up and halfway along in stand opposite where the players come out. He suddenly leaps to his feet cheering. Cut to players tunnel and one player emerging and a referee with ball. They kick off. Player goes straight down field and scores. Spectator disapppointed. A quick shot of flying saucer again. Studio: the laboratory again. Charles is looking through microscope, when the door flies open and she bursts in.
She | Charles! Thank goodness I've found you! It's mummy!
Charles | Hello mummy.
She | No, no, mummy's turned into a Scotsman...
Charles | Oh how horrible... Will they stop at nothing?
She | I don't know - do you think they will?
Charles | I meant that rhetorically.
She | What does rhetorically mean?
Charles | It means, I didn't expect an answer.
She | Oh I see. Oh, you're so clever, Charles.
Charles | Did mummy say anything as she changed?
She | (with an air of tremendous revelation) Yes! she did, now you come to mention it
| A long pause as he waits expectantly.
Charles | Well, what was it?
She | Oh, she said ... 'Them!' (thrilling chord of jangling music and quick zoom into her face) Is there someone at the door?
Charles | No ... It's just the incidental music for this scene.
She | Oh I see...
Charles | 'Them' ... Wait a minute!
She | A whole minute?
Charles | No, I meant that metaphorically ... 'Them' ... 'Them' ... She was obviously referring to the people who turned her into a Scotsman. If only we knew who 'They' were ... And why 'They' were doing it... Who are 'Them'?
| Crashing chord... cut to a small still of a Scottish crofier's cottage on a lonely moor. Slow zoom in on the cottage.
American Voice | Then suddenly a clue turned up in Scotland. Mr Angus Podgorny, owner of a Dunbar menswear shop, received an order for 48,000,000 kilts from the planet Skyron in the Galaxy of Andromeda.
| Mix to interior of highland menswear shop. An elderly Scottish couple are poring over a letter which they have on the counter. Oil lamps etc.
Mrs Podgorny | Angus how are y'going to get 48,000,000 kilts into the van?
Angus | I'll have t'do it in two goes.
Mrs Podgorny | D'you not ken that the Galaxy of Andromeda is two million, two hundred thousand light years away?
Angus | Is that so?
Mrs Podgorny | Aye ... and you've never been further than Berwick-on-Tweed...
Angus | Aye ... but think o' the money dear ... £18.10.0d a kilt ...that's ... (calculates with abacus) £900,000,000 - and that's without sporrans!
Mrs Podgorny | Aye ... I think you ought not to go, Angus.
Angus | (with visionary look in his eyes) Aye ... we'd be able to afford writing paper with our names on it... We'd be able to buy that extension to the toilet...
Mrs Podgorny | Aye ... but he hasn't signed the order yet, has he?
Angus | Who?
Mrs Podgorny | Ach ... the man from Andromeda.
Angus | Och ... well ... he wasna really a man, d'you ken ...
| Creepy music starts to edge in.
Mrs Podgorny | (narrowing eyes) Not really a man?
Angus | (sweating as the music rises) He was as strange a thing as ever I saw, or ever I hope to see, God willing. He was a strange unearthly creature - a quivering, glistening mass...
Mrs Podgorny | Angus Podgorny, what do y'mean?
Angus | He wasna so much a man as... a blancmange!
| Jarring chord.
| Police station: a police sergeant is talking over the counter to a girl dressed in a short frilly tennis dress. She holds a racquet and tennis balls.
Sergeant | A blancmange, eh?
Girl | Yes, that's right. I was just having a game of doubles with Sandra and Jocasta, Alec and David...
Sergeant | Hang on!
Girl | What?
Sergeant | There's five.
Girl | What?
Sergeant | Five people . . . how do you play doubles with five people?
Girl | Ah, well ... we were...
Sergeant | Sounds a bit funny if you ask me ... playing doubles with five people...
Girl | Well we often play like that... Jocasta plays on the side receiving service...
Sergeant | Oh yes?
Girl | Yes. It helps to speed the game up and make it a lot faster, and it means Jocasta isn't left out.
Sergeant | Look, are you asking me to believe that the five of you was playing doubles, when on the very next court there was a blancmange playing by itself?.
Girl | That's right, yes.
Sergeant | Well answer me this then - why didn't Jocasta play the blancmange at singles, while you and Sandra and Alec and David had a proper game of doubles with four people?
Girl | Because Jocasta always plays with us. She's a friend of ours.
Sergeant | Call that friendship? Messing up a perfectly good game of doubles?
Girl | It's not messing it up, officer, we like to play with five.
Sergeant | Look it's your affair if you want to play with five people ... but don't go calling it doubles. Look at Wimbledon, right? If Fred Stolle and Tony Roche played Charlie Pasarell and Cliff Drysdale and Peaches Bartcowitz... they wouldn't go calling it doubles.
Girl | But what about the blancmange?
Sergeant | That could play Ann Haydon-Jones and her husband Pip.
| Cut back to Podgorny's shop. He and his wife are frozen in the positions in which we left them. They pick up the conversation as if nothing had happened.
Mrs Podgorny | Oh, a blancmange gave you an order for 48,000,000 kilts?
Angus | Aye!
Mrs Podgorny | And you believed it?
Angus | Aye, I did.
Mrs Podgorny | Och, you're a stupid man, Angus Podgorny.
Angus | (getting a little angry) Oh look woman, how many kilts did we sell last year? Nine and a half, that's all. So when I get an order for 48,000,000, I believe it - you bet I believe it.
Mrs Podgorny | Even if it's from a blancmange?
Angus | Och, woman, if a blancmange is prepared to come 2,200,000 light years to purchase a kilt, they must be fairly keen on kilts. So cease yer prattling woman and get sewing. This could be the biggest breakthrough in kilts since the Provost of Edinburgh sat on a spike. Mary, we'll be rich! We'll be rich!
Mrs Podgorny | Oh, but Angus... he hasna given you an earnest of his good faith!
Angus | Ah mebbe not but he has gi' me this... (brings out piece of folded paper from sporran)
Mrs Podgorny | What is it now?
Angus | An entry form for the British Open Tennis Championships at Wimbledon Toon ... signed and seconded.
Mrs Podgorny | Och, but Angus, ye ken full well that Scots folk dinna know how to play the tennis to save their lives.
Angus | Aye, but I must go though dear, I dinna want to seem ungrateful.
Mrs Podgorny | Ach! Angus, I wilna let you make a fool o'yourself.
Angus | But I must.
Mrs Podgorny | Och, no you'll not ...
| Close-up on Angus.
Angus | Oh, Mary... (suddenly we hear a strange creaking and a slurping noise; a look of horror comes into his eyes) Oh, oh, Mary! Look out! Look out!
| Big close-up of Mrs Podgorny's eyes starting out from head.
Mrs Podgorny | Urrgh. It's the blancmange.
| Blur focus. Cut to a desk for police spokesman. A peaked-capped policeman sits there, reading 'The Rise and Fall of the Roman Empire' by Googie Withers. He lowers book and talks chattily to camera.
Policeman | Oh, now this is where Mr Podgorny could have saved his wife's life. If he'd gone to the police and told them that he'd been approached by unearthly beings from the Galaxy of Andromeda, we'd have sent a man round to investigate. As it was he did a deal with a blancmange, and the blancmange ate his wife. So if you're going out, or going on holiday, or anything strange happens involving other galaxies, just nip round to your local police station, and tell the sergeant on duty - or his wife - of your suspicions. And the same goes for dogs. So I'm sorry to have interrupted your exciting science fiction story ... but, then, crime's our business you know. So carry on viewing, and my thanks to the BBC for allowing me to have this little chat with you. Goodnight. God bless, look after yourselves.
| He is hit on the head by knight in suit of armour with raw chicken. Cut to CID office: a plainclothes detective is sitting in his office. Podgorny is sobbing.
Detective | (softly and understandingly) Do sit down, Mr Podgorny... I... I ... think what's happened is ... terribly ... terribly... funny .... tragic. But you must understand that we have to catch the creature that ate your wife, and if you could help us answer a few questions, we may be able to help save a few lives. I know this is the way your wife would have wanted it.
| He is sitting on the desk next to Podgorny. Podgorny with superhuman control makes a great effort to stop sobbing.
Angus | Aye ... I'll ... do ... my best, sergeant.
Detective | (slapping Podgorny) Detective Inspector!
Angus | Er, detective inspector.
Detective | (getting up and talking sharply and fast) Now then. The facts are these. You received an order for 48,000,000 kilts from a blancmange from the planet Skyron in the Galaxy of Andromeda ... you'd just shown your wife an entry form for Wimbledon, which you'd filled in... when you turned round and saw her legs disappearing into a blancmange. Is that correct?
Angus | Yes, sir.
Detective | Are you mad?
Angus | No, sir.
Detective | Well that's a relief. 'Cos if you were, your story would be less plausible. (detective brings out photograph of blancmange) Now then, do you recognize this?
Angus | (with a squeak of fear) Oh yes. That's the one that ate my Mary!
Detective | Good. His name's Riley... Jack Riley... He's that most rare of criminals ... a blancmange impersonator and cannibal.
Angus | But what about the 48,000,000 kilts and the Galaxy of Andromeda?
Detective | I'm afraid that's just one of his stories. You must understand that a blancmange impersonator and cannibal has to use some pretty clever stories to allay suspicion.
Angus | Then you mean...
Detective | Yes.
Angus | But...
Detective | How?
Angus | Yes.
Detective | Well...
Angus | Not?
Detective | I'm afraid so.
Angus | Why?
Detective | Who knows?
Angus | Do you think?
Detective | Could be.
Angus | But...
Detective | I know.
Angus | She was...
Detective | Yes.
| Suddenly, we hear a strange noise. Angus looks frightened. Detective narrows his eyes and walks over to the door.
Detective | Good lord what's that? (he opens the door and we get a close-up of his staring eyes) Ah, Riley! Come to give yourself up have you, Riley? (with sudden fear) Eh Riley? Riley! Riley! It's not Riley!
| Eating noises. He is dragged out of camera shot. Refocus on Angus ... he averts his eyes as we hear the detective inspector off-screen.
Detective | (off-screen) It's an extra-terrestial being! Agggh!
| Jarring chord: Angus shuts his eyes. Cut back to laboratory: she is sitting suggestively on a stool. He is pacing up and down looking intense.
Charles | So, everyone in England is being turned into Scotsmen, right?
She | Yes.
Charles | Now, which is the worst tennis-playing nation in the world?
She | Er ... Australia.
Charles | No. Try again.
She | Australia?
Charles | (testily) No... try again but say a different place.
She | Oh, I thought you meant I'd said it badly.
Charles | No, course you didn't say it badly. Now hurry.
She | Er, Czechoslovakia.
Charles | No! Scotland!
She | Of course.
Charles | Now ... now these blancmanges, apart from the one that killed Mrs Podgorny have all appeared in which London suburb?
She | Finchley?
Charles | No. Wimbledon ... Now do you begin to see the pattern? With what sport is Wimbledon commonly associated?
| She is thinking really hard.
Norman Hackforth | (off-screen) For viewers at home, the answer is coming up on your screens. Those of you who wish to play it the hard way, stand upside down with your head in a bucket of piranha fish. Here is the question once again.
Charles | With what sport is Wimbledon commonly associated?
| SUPERIMPOSED CAPTION: 'TENNIS'
She | Cricket.
Charles | No.
She | Pelote?
Charles | No. Wimbledon is most commonly associated with tennis.
She | Of course! Now I see!
Charles | Yes, it all falls into place!
She | The blancmangcs are really Australians trying to get the rights of the pelota rules from the Czech publishers!
Charles | (heavily) No ... not quite ... but, er, just look in here.
| He indicates microscope. As she eagerly bends to look into it he picks up a sock filled with sand and without looking strikes her casually over the head with it. She collapses out of sight under desk. He continues to think out loud.
Charles | Yes. So these blancmanges, blancmange-shaped creatures come from the planet Skyron in the Galaxy of Andromeda. They order 48,000,000 kilts from a Scottish menswear shop ... turn the population of England into Scotsmen (well known as the worst tennis-playing nation on Earth) thus leaving England empty during Wimbledon fortnight! Empty during Wimbledon fortnight ... what's more the papers are full of reports of blancmanges appearing on tennis courts up and down the country - practising. This can only mean one thing!
| Flash up caption quickly:
Voice Over | (and CAPTION) 'THEY MEAN TO WIN WIMBLEDON'
Charles | They mean to win Wimbledon!
| Cut to commentator in his box.
Commentator | Well, here at Wimbledon, it's been a most extraordinary week's tennis. The blancmanges have swept the board, winning match after match. Here are just a few of the results: Billie-Jean King eaten in straight sets, Laver smothered whole after winning the first set, and Poncho Gonzales, serving as well as I've never seen him, with some superb volleys and decisive return volleys off the back hand, was sucked through the net at match point and swallowed whole in just under two minutes. And so, here on the final day, there seems to be no players left to challenge the blancmanges. And this could be their undoing, Dan: as the rules of Wimbledon state quite clearly that there must be at least one human being concerned in the final. (we see a three-foot-high blancmange being shepherded onto a tennis court by a Scotsman) Well the blancmange is coming out onto the pitch now, and (suddenly exalted) there is a human with it. It's Angus Podgorny! The plucky little Scottish tailor ... upon whom everything depends. And so it's Podgorny versus blancmange in this first ever Intergalactic Wimbledon!
| Cut to the centre court at Wimbledon or if we can't get it, number one will do. Blancmange and Podgorny on opposite sides net. Another blancmange sitting in umpire's chair. Blancmange serves... a real sizzling ace. Podgorny, who in any case is quivering with fear, doesn't see it.
Commentator's Voice | And it's blancmange to serve and it's a good one.
Blancmange Umpire | Blurb blurble blurb.
Voice Over | Fifteen love.
| Blancmange serves again, and again Podgorny misses hopelessly and pathetically. Collage of speeded-up versions of blancmange sewing and Podgorny missing. Cut to scoreboard:
BLANCMANGE: | 40
PODGORNY: | 0
Cut back to the court. Podgorny is serving and each time he fails to hit the ball altogether.
Commentator's Voice | And Podgorny fails to even hit the ball ... but this is no surprise as he hasn't hit the ball once throughout this match. So it's 72 match points to the blancmange now... Podgorny prepares to serve again.
| Podgorny fails to serve and we see the scoreboard:
BLANCMANGE: | 6 6 5 40
PODGORNY: | 0 0
Commentator's Voice | This is indeed a grim day for the human race, Dan.
| Just as Podgorny is about to serve we see Mr and Mrs Brainsample jump onto the court brandishing forks and spoons and with napkins tucked into their necks.
Commentator's Voice | But what's this? Two spectators have rushed onto the pitch with spoons and forks... what are they going to do?
| Cut to laboratory.
Charles | They mean to eat the blancmange.
| The girl pulls herself up from where she was slumped by microscope. He knocks her out again with a sand-filled sock. Cut back to Wimbledon. Mr and Mrs Brainsample chasing blancmange and eating it.
Commentator's Voice | And they're eating the blancmange ... Yes! The blancmange is leaving the court... it's abandoning the game! This is fantastic!
| Cut to Mr and Mrs Brainsample covered in bits of blancmange and licking their fingers.
American Voice | Yes it was Mr and Mrs Samuel Brainsample, who, after only a brief and misleadling appearance in the early part of the film, returned to save the Earth ... but why?
Mr Brainsample | Oh, well you see we love blancmanges. My wife makes them.
American Voice | She makes blancmanages that size?
Mr Brainsample | Oh, yes. You see we're from the planet Skyron in the Galaxy of Andromeda, and they're all that size there. We tried to tell you at the beginning of the film but you just panned off us.
| Cut back to Podgorny on court still trying to serve; at last he makes contact and runs backward and forward to receive his own services.
American Voice | So the world was saved! And Angus Podgorny became the first Scotsman to win Wimbledon... fifteen years later.
| ROLLER CAPTION: 'YOU'RE NO FUN ANYMORE'...(CREDITS)